@@ -22,7 +22,7 @@ ENV = os.environ['ENV'] # Must be set
 SERVICE_NAME = os.environ['SERVICE_NAME']
 LOCAL_DEPLOYMENT = os.getenv('LOCAL_DEPLOYMENT') # Optional
 
-deployment_platform = 'gc' # 'cdf'
+deployment_platform = 'cdf' # 'cdf'
 
 
 def deploy(model_settings):
